@@ -41,8 +41,8 @@ from gutils import read_file
 from gettext import gettext as _
 
 try:
-    import EasyDialogs
-except:
+    pass
+except Exception:
     pass
 
 log = logging.getLogger('Griffith')
@@ -78,7 +78,7 @@ def create(self):
                 else:
                     log.debug('Creating zip file without compression')
                     mzip = zipfile.ZipFile(zipfilename, 'w')
-            except:
+            except Exception:
                 gutils.error(_("Error creating backup"), self.widgets['window'])
                 return False
             log.debug('Preparing data and saving it to the zip archive')
@@ -168,7 +168,7 @@ def merge_db(src_db, dst_db):  # FIXME
     dst_db.session.rollback()  # cancel all pending operations
     src_session = src_db.Session()  # create new session
     dst_session = dst_db.Session()  # create new session
-    movies = src_session.query(db.Movie).count()
+    src_session.query(db.Movie).count()
     for movie in src_session.query(db.Movie).all():
         if dst_session.query(db.Movie).filter_by(o_title=movie.o_title).first() is not None:
             continue
@@ -296,7 +296,7 @@ def restore(self, merge=False):
             self.populate_treeview()
         #gutils.info(_("Databases merged!\n\nProcessed movies: %s\nMerged movies: %s"%(movies, merged)), self.widgets['window'])
         gutils.info(_("Backup restored"), self.widgets['window'])
-    except:
+    except Exception:
         log.exception('')
         raise
     finally:
