@@ -25,7 +25,7 @@ __revision__ = '$Id$'
 import logging
 import os.path
 
-from sqlalchemy.exc import *
+from sqlalchemy.exc import IntegrityError, OperationalError
 
 import db
 import gutils
@@ -418,7 +418,7 @@ def convert_from_old_db(config, source_file, destination_file, locations):  #{{{
     new_db = GriffithSQL(config, locations['home'], fallback=False)
 
     # collections
-    collection_mapper = {'': None, '': None, 0: None, '0': None, -1: None, '-1': None}
+    collection_mapper = {'': None, 0: None, '0': None, -1: None, '-1': None}
     # loaned status will be set later - buggy databases :-(
     old_cursor.execute("SELECT id, name FROM collections;")
     for i in old_cursor.fetchall():
@@ -432,7 +432,7 @@ def convert_from_old_db(config, source_file, destination_file, locations):  #{{{
         collection_mapper[i[0]] = o.collection_id
 
     # volumes
-    volume_mapper = {'': None, '': None, 0: None, '0': None, -1: None,
+    volume_mapper = {'': None, 0: None, '0': None, -1: None,
                      '-1': None}
     # loaned status will be set later - buggy databases :-(
     old_cursor.execute("SELECT id, name FROM volumes;")
@@ -460,7 +460,7 @@ def convert_from_old_db(config, source_file, destination_file, locations):  #{{{
         person_mapper[i[0]] = o.person_id
 
     # languages
-    language_mapper = {'': None, '': None, 0: None, '0': None, -1: None, '-1': None}
+    language_mapper = {'': None, 0: None, '0': None, -1: None, '-1': None}
     old_cursor.execute("SELECT id, name FROM languages;")
     for i in old_cursor.fetchall():
         o = new_db.session.query(db.Lang).filter_by(name=i[1]).first()
@@ -479,7 +479,7 @@ def convert_from_old_db(config, source_file, destination_file, locations):  #{{{
     # media
     # FIXME: what may have been the intention for the two "''" keys, a key is
     #  unique in a dictionary?
-    medium_mapper = {'': None, '': None, 0: None, '0': None, -1: None, '-1': None}
+    medium_mapper = {'': None, 0: None, '0': None, -1: None, '-1': None}
     old_cursor.execute("SELECT id, name FROM media;")
     for i in old_cursor.fetchall():
         o = new_db.session.query(db.Medium).filter_by(name=i[1]).first()
