@@ -21,62 +21,65 @@ __revision__ = '$Id$'
 # You may use and distribute this software under the terms of the
 # GNU General Public License, version 2 or later
 
+from gettext import gettext as _
 import locale
 import logging
 import os
-import string
-import sys
 import tempfile
 import threading
 import time
-from urllib.request import *
+import urllib.error
+import urllib.parse
+import urllib.request
 from urllib.parse import quote
+from urllib.request import urlcleanup, FancyURLopener
+
 from gi.repository import Gtk
 import gutils
-import urllib.request, urllib.error, urllib.parse
 
 log = logging.getLogger("Griffith")
 
 
 class Movie(object):
-    cast = None
-    classification = None
-    country = None
-    director = None
-    genre = None
-    image = None
-    notes = None
+    cast = ''
+    classification = ''
+    country = ''
+    director = ''
+    genre = ''
+    image = ''
+    notes = ''
     number = None
-    o_site = None
-    o_title = None
-    plot = None
-    rating = None
-    runtime = None
-    site = None
-    studio = None
-    title = None
-    trailer = None
-    year = None
-    screenplay = None
-    cameraman = None
-    resolution = None
-    barcode = None
+    o_site = ''
+    o_title = ''
+    plot = ''
+    rating = ''
+    runtime = ''
+    site = ''
+    studio = ''
+    title = ''
+    trailer = ''
+    year = ''
+    screenplay = ''
+    cameraman = ''
+    resolution = ''
+    barcode = ''
 
-    movie_id = None
+    movie_id = ''
     debug = False
-    locations = None
+    locations = ''
     engine_author = None
     engine_description = None
     engine_language = None
     engine_name = None
     engine_version = None
     page = None
-    url = None
-    image_url = None
+    url = ''
+    image_url = ''
     encode = 'utf-8'
     fields_to_fetch = []
     progress = None
     useurllib2 = False
+    parent_window = None  # had been defined outside __init__
 
     # functions that plugin should implement: {{{
     def initialize(self):
@@ -144,7 +147,7 @@ class Movie(object):
 
     def get_year(self):
         pass
-    #}}}
+    # }}}
 
     def __getitem__(self, key):
         return getattr(self, key)
@@ -159,12 +162,14 @@ class Movie(object):
             #
             if self.progress is None:
                 self.progress = Progress(parent_window)
-            self.progress.set_data(parent_window, _("Checking connection"), _("Wait a moment"), True)
+            self.progress.set_data(
+                parent_window, _("Checking connection"), _("Wait a moment"),
+                True)
             #
             # check for internet connection
-            #
-            urllib.request.urlopen("http://www.google.com")
-            self.progress.set_data(parent_window, _("Fetching data"), _("Wait a moment"), True)
+            urllib.request.urlopen("https://www.google.com")
+            self.progress.set_data(
+                parent_window, _("Fetching data"), _("Wait a moment"), True)
             #
             # get the page
             #
@@ -172,21 +177,28 @@ class Movie(object):
                 return None
             return True
 
-        except:
+        except Exception as exc:
+            log.error(f"[E017]Caught too broad try-except,"
+                      f" {type(exc).__name__}: {exc}")
             self.progress.hide()
             gutils.error(_("Connection failed."))
             return False
 
     def open_page(self, parent_window=None, url=None):
+        log.debug("[open_page]")
         if url is None:
             url_to_fetch = self.url
         else:
             url_to_fetch = url
         if parent_window is not None:
             self.parent_window = parent_window
-        self.progress.set_data(parent_window, _("Fetching data"), _("Wait a moment"), False)
-        retriever = Retriever(url_to_fetch, self.parent_window, self.progress, useurllib2=self.useurllib2)
+        self.progress.set_data(
+            parent_window, _("Fetching data"), _("Wait a moment"), False)
+        retriever = Retriever(
+            url_to_fetch, self.parent_window, self.progress,
+            useurllib2=self.useurllib2)
         retriever.start()
+        log.debug(f"self.progress.status: retriever.start(), url: {self.url}")
         while retriever.is_alive():
             self.progress.pulse()
             if self.progress.status:
@@ -197,6 +209,7 @@ class Movie(object):
         try:
             if retriever.exception is None:
                 if retriever.html:
+                    log.debug(f"HTML retrieval: {retriever.html}")
                     ifile = open(retriever.html[0], "r", encoding=self.encode, errors='replace')
                     try:
                         data = ifile.read()
@@ -206,9 +219,11 @@ class Movie(object):
                     if len(data) > 2 and data[0:2] == '\037\213':
                         data = gutils.decompress(data)
             else:
+                log.warning(f"Unable to retrieve: {retriever.exception}")
                 gutils.urllib_error(_("Connection error"), self.parent_window)
-        except IOError:
-            log.exception('')
+        except IOError as exc:
+            log.exception(f"IOError: {exc}")
+        log.debug(f"Retrieved data size: {len(data)}")
         if url is None:
             self.page = data
         urlcleanup()
@@ -217,11 +232,19 @@ class Movie(object):
     def fetch_picture(self):
         if self.image_url:
             tmp_dest = tempfile.mktemp(prefix='poster_', dir=self.locations['temp'])
+            log.debug(f"fetch_picture: tmp_dest: {tmp_dest}")
             self.image = tmp_dest.split('poster_', 1)[1]
+            log.debug(f"fetch_picture: self.image: {self.image}")
             dest = "%s.jpg" % tmp_dest
             try:
-                self.progress.set_data(self.parent_window, _("Fetching poster"), _("Wait a moment"), False)
-                retriever = Retriever(self.image_url, self.parent_window, self.progress, dest, useurllib2=self.useurllib2)
+                self.progress.set_data(
+                    self.parent_window,
+                    _("Fetching poster"),
+                    _("Wait a moment"),
+                    False)
+                retriever = Retriever(self.image_url, self.parent_window,
+                                      self.progress, dest,
+                                      useurllib2=self.useurllib2)
                 retriever.start()
                 while retriever.is_alive():
                     self.progress.pulse()
@@ -230,17 +253,19 @@ class Movie(object):
                     while Gtk.events_pending():
                         Gtk.main_iteration()
                 urlcleanup()
-            except:
-                log.exception('')
+            except Exception as exc:
+                log.exception(f"[E018]Caught too broad try-except,"
+                              f" {type(exc).__name__}: {exc}")
                 self.image = ""
                 try:
                     os.remove("%s.jpg" % tmp_dest)
-                except:
-                    log.info("Can't remove %s file" % tmp_dest)
+                except Exception as exc:
+                    log.info(f"Can't remove {tmp_dest} file, {exc}")
         else:
             self.image = ""
 
     def parse_movie(self):
+        log.debug("[parse_movie]")
         try:
             fields = list(self.fields_to_fetch)  # make a copy
 
@@ -266,6 +291,7 @@ class Movie(object):
                 fields.pop(fields.index('cast'))
             if 'plot' in fields:
                 self.get_plot()
+                log.debug(f"self.plot: {self.plot}")
                 self.plot = gutils.clean(self.plot)
                 if not isinstance(self.plot, str):
                     self.plot = gutils.gdecode(self.plot, self.encode)
@@ -277,7 +303,9 @@ class Movie(object):
                     self.notes = gutils.gdecode(self.notes, self.encode)
                 fields.pop(fields.index('notes'))
             if 'image' in fields:
+                log.debug(f"image in fields: {fields}")
                 self.get_image()
+                log.debug(f"self.image_url: {self.image_url} self.image: {self.image}")
                 self.fetch_picture()
                 fields.pop(fields.index('image'))
 
@@ -293,8 +321,8 @@ class Movie(object):
             if 'title' in self.fields_to_fetch and self.title is not None:
                 if self.title[:4] == 'The ':
                     self.title = self.title[4:] + ', The'
-        except:
-            log.exception('')
+        except Exception as exc:
+            log.exception(f"{exc}")
         finally:
             # close the progress dialog which was opened in get_movie
             self.progress.hide()
@@ -332,16 +360,17 @@ class SearchMovie(object):
             #
             return self.search(parent_window)
         finally:
-            # dont forget to hide the progress dialog
+            # don't forget to hide the progress dialog
             self.progress.hide()
 
     def open_search(self, parent_window, destination=None):
+        log.debug("[open_search]")
         self.titles = [""]
         self.ids = [""]
 
         self.title = quote(self.title)
         if self.url.find('%s') > 0:
-            self.url = self.url % self.title
+            self.url %= self.title
             self.url = self.url.replace(' ', '%20')
         else:
             if not self.usepostrequest:
@@ -351,9 +380,12 @@ class SearchMovie(object):
         self.progress.set_data(parent_window, _("Searching"), _("Wait a moment"), True)
         if self.usepostrequest:
             postdata = self.get_postdata()
-            retriever = Retriever(url, parent_window, self.progress, destination, useurllib2=self.useurllib2, postdata=postdata)
+            retriever = Retriever(
+                url, parent_window, self.progress, destination,
+                useurllib2=self.useurllib2, postdata=postdata)
         else:
-            retriever = Retriever(url, parent_window, self.progress, destination, useurllib2=self.useurllib2)
+            retriever = Retriever(url, parent_window, self.progress,
+                                  destination, useurllib2=self.useurllib2)
         retriever.start()
         while retriever.is_alive():
             self.progress.pulse()
@@ -368,11 +400,8 @@ class SearchMovie(object):
                     # don't care about the content
                     return True
                 if retriever.html:
-                    ifile = open(retriever.html[0], 'rb')
-                    try:
+                    with open(retriever.html[0], 'rb') as ifile:
                         self.page = ifile.read()
-                    finally:
-                        ifile.close()
                     # check for gzip compressed pages before decoding to unicode
                     if len(self.page) > 2 and self.page[0:2] == '\037\213':
                         self.page = gutils.decompress(self.page)
@@ -383,22 +412,22 @@ class SearchMovie(object):
                 self.progress.hide()
                 gutils.urllib_error(_("Connection error"), parent_window)
                 return False
-        except IOError:
-            log.exception('')
+        except IOError as exc:
+            log.exception(f"IOError: {exc}")
         finally:
             urlcleanup()
         return True
-    
+
     def get_postdata(self):
         # sample, depends on target site
-        #return {'title' : self.Title, 'category' : 'movieTitel' }
+        # return {'title' : self.Title, 'category' : 'movieTitel' }
         return {}
 
 
 class Retriever(threading.Thread):
 
-    def __init__(self, URL, parent_window, progress, destination=None, useurllib2=False, postdata=None):
-        self.URL = URL
+    def __init__(self, url, parent_window, progress, destination=None, useurllib2=False, postdata=None):
+        self.URL = url
         self.html = None
         self.exception = None
         self.destination = destination
@@ -413,39 +442,61 @@ class Retriever(threading.Thread):
         try:
             if self.useurllib2:
                 if self.postdata:
-                    encodedpostdata = urlencode(self.postdata)
-                    self.html = urlretrieve2(self.URL, self.destination, self.hook, encodedpostdata)
+                    encodedpostdata = urllib.parse.urlencode(self.postdata)
+                    self.html = urlretrieve2(self.URL, self.destination,
+                                             self.hook, encodedpostdata)
+                    log.debug(f"urllib2 POST HTML=\n{self.html}")
                 else:
-                    self.html = urlretrieve2(self.URL, self.destination, self.hook)
+                    self.html = urlretrieve2(self.URL, self.destination,
+                                             self.hook)
             else:
                 if self.postdata:
-                    encodedpostdata = urlencode(self.postdata)
-                    self.html = urlretrieve(self.URL, self.destination, self.hook, encodedpostdata)
+                    encodedpostdata = urllib.parse.urlencode(self.postdata)
+                    log.debug(f"encodedpostdata={encodedpostdata}")
+                    self.html = urlretrieve(self.URL, self.destination,
+                                            self.hook, encodedpostdata)
+                    log.debug(f"urllib POST data={self.postdata} "
+                              f"HTML=\n{self.html}")
                 else:
-                    self.html = urlretrieve(self.URL, self.destination, self.hook)
+                    try:
+                        log.debug("No encodedpostdata")
+                        self.html = urlretrieve(self.URL, self.destination,
+                                                self.hook)
+                        log.debug(f"urllib POST HTML=\n{self.html}")
+                    except ValueError as exc:
+                        msg = f"Could not retrieve data from URL {self.URL}"
+                        log.debug(f"No exception 'ValueError', "
+                                  f"self.html={self.html}")
+                        log.error(f"{msg}, {exc}")
+                        gutils.error(_(msg))
             if self.progress.status:
+                log.debug(f"self.progress.status={self.progress.status}")
                 self.html = []
-        except Exception as e:
-            log.exception('')
-            self.exception = e
+        except Exception as exc:
+            log.exception(f"[E019]Caught too broad try-except,"
+                          f" {type(exc).__name__}: {exc}")
+            self.exception = exc
 
-    def hook(self, count, blockSize, totalSize):
-        if totalSize == -1:
+    def hook(self, count, block_size, total_size):
+        if total_size == -1:
             pass
         else:
             try:
-                downloaded_percentage = min((count * blockSize * 100) / totalSize, 100)
-            except:
-                downloaded_percentage = 100
+                min((count * block_size * 100) /
+                                            total_size, 100)
+            except Exception:
+                pass
             if count != 0:
-                downloaded_kbyte = int(count * blockSize / 1024.0)
-                filesize_kbyte = int(totalSize / 1024.0)
+                int(count * block_size / 1024.0)
+                int(total_size / 1024.0)
 
 #
 # use own derived URLopener class because we need to set a correct User-Agent
-# string for some web sites. The default is 'Python-urllib/<version>'
+# string for some websites. The default is 'Python-urllib/<version>'
 # which not all sites accepting. (zelluloid.de for example)
 #
+
+
 _uaurlopener = None
 _tempfilecleanup = None
 
@@ -454,15 +505,29 @@ def urlretrieve(url, filename=None, reporthook=None, data=None):
     global _uaurlopener
     if not _uaurlopener:
         _uaurlopener = UAFancyURLopener()
-    log.debug("url :%s:", url)
-    return _uaurlopener.retrieve(url, filename, reporthook, data)
+    log.debug(f"url='{url}' _uaurlopener={_uaurlopener}")
+    if _uaurlopener and url:
+        try:
+            ua_url_opener = _uaurlopener.retrieve(url, filename, reporthook,
+                                                  data)
+        except (AttributeError, OSError) as exc:
+            msg = f"Retrieving URL={url}. filename={filename} failed. exc={exc}"
+            log.error(msg)
+            gutils.error(msg)
+            ua_url_opener = None
+    else:
+        return None
+    if ua_url_opener:
+        return _uaurlopener.retrieve(url, filename, reporthook, data)
+    else:
+        return None
 
 
 def urlretrieve2(url, filename=None, reporthook=None, data=None):
     global _tempfilecleanup
     headers = {
-        #'User-Agent': 'Mozilla/5.0 (compatible; MSIE 10.0; Windows NT 6.2; Trident/6.0; MSAppHost/1.0)',
-        #'User-Agent': 'Dalvik/1.6.0 (Linux; U; Android 4.2.2; Nexus 4 Build/JDQ39E)'
+        # 'User-Agent': 'Mozilla/5.0 (compatible; MSIE 10.0; Windows NT 6.2; Trident/6.0; MSAppHost/1.0)',
+        # 'User-Agent': 'Dalvik/1.6.0 (Linux; U; Android 4.2.2; Nexus 4 Build/JDQ39E)'
         'User-Agent': 'Dalvik/1.2.0 (Linux; U; Android 2.2.2; Huawei U8800-51 Build/HWU8800B635)',
         'Cache-Control': 'no-cache',
         'Pragma': 'no-cache',
@@ -475,24 +540,22 @@ def urlretrieve2(url, filename=None, reporthook=None, data=None):
         if not _tempfilecleanup:
             _tempfilecleanup = TempFileCleanup()
         _tempfilecleanup._tempfiles.append(filename)
-        tfp = os.fdopen(fd, 'wb')
     else:
-        tfp = file(filename, 'wb')
-    while 1:
-        block = response.read(4096)
-        if block == "":
-            break
-        tfp.write(block)
-    tfp.close()
+        fd = filename
+    with open(fd, 'wb') as tfp:
+        while 1:
+            block = response.read(4096)
+            if block == "":
+                break
+            tfp.write(block)
     return [filename, response.info()]
 
+
 def get_locale():
-  os_locale = locale.getdefaultlocale()[0]
-
-  if os_locale is None:
-    return "en-US"
-
-  return os_locale.replace('_', '-')
+    os_locale = locale.getdefaultlocale()[0]
+    if os_locale is None:
+        return "en-US"
+    return os_locale.replace('_', '-')
 
 
 class UAFancyURLopener(FancyURLopener):
@@ -511,7 +574,12 @@ class UAFancyURLopener(FancyURLopener):
         # prevent blocking calls which doesn't come back
         import socket
         socket.setdefaulttimeout(20)
-        return FancyURLopener.open(self, fullurl, data)
+        try:
+            fancy_url_opener_fp = FancyURLopener.open(self, fullurl, data)
+        except urllib.error.URLError as exc:
+            log.error(f"Can't open URL {fullurl}, exception: {exc}")
+            fancy_url_opener_fp = None
+        return fancy_url_opener_fp
 
 
 class TempFileCleanup:
@@ -565,7 +633,7 @@ class Progress:
         self.dialog.hide()
 
     def set_data(self, parent_window, title, message, showit):
-        #self.dialog.set_parent(parent_window)
+        # self.dialog.set_parent(parent_window)
         self.dialog.set_title(title)
         self.label.set_markup(message)
         if showit is True:
